@@ -12,9 +12,10 @@ use IO::All::Base -base;
 use File::Spec();
 use Symbol();
 use Fcntl;
+use Cwd ();
 
 # ABSTRACT: IO::All of it to Graham and Damian!
-our $VERSION = '0.55'; # VERSION
+our $VERSION = '0.56'; # VERSION
 our @EXPORT = qw(io);
 
 #===============================================================================
@@ -435,7 +436,11 @@ proxy_open 'getc';
 #===============================================================================
 # File::Spec Interface
 #===============================================================================
-sub canonpath {my $self = shift; File::Spec->canonpath($self->pathname) }
+sub canonpath {my $self = shift;
+   Cwd::abs_path($self->pathname) ||
+      File::Spec->canonpath($self->pathname)
+}
+
 sub catdir {
     my $self = shift;
     my @args = grep defined, $self->name, @_;
