@@ -53,7 +53,11 @@ sub target {
     *$self->{target} = $new;
 }
 
-=head1 NAME 
+sub exists { -l shift->pathname }
+
+=encoding utf8
+
+=head1 NAME
 
 IO::All::Link - Symbolic Link Support for IO::All
 
@@ -69,9 +73,9 @@ Ingy döt Net <ingy@cpan.org>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006. Ingy döt Net. All rights reserved.
+Copyright (c) 2004. Brian Ingerson.
 
-Copyright (c) 2004. Brian Ingerson. All rights reserved.
+Copyright (c) 2006, 2008. Ingy döt Net.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
